package VMOMI::HostGraphicsInfoGraphicsType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
